@@ -1,11 +1,8 @@
 package Pcore::API::SCM;
 
-use Pcore -const, -class, -export => { CONST => [qw[$SCM_TYPE_HG $SCM_TYPE_GIT]] };
-
-const our $SCM_TYPE_HG  => 1;
-const our $SCM_TYPE_GIT => 2;
-
-require Pcore::API::SCM::Upstream;
+use Pcore -class;
+use Pcore::API::SCM::Const qw[:ALL];
+use Pcore::API::SCM::Upstream;
 
 has type => ( is => 'ro', isa => Enum [ $SCM_TYPE_HG, $SCM_TYPE_GIT ], required => 1 );
 has root => ( is => 'ro', isa => Str, required => 1 );
@@ -83,7 +80,7 @@ sub scm_init ( $self, $root, $type = $SCM_TYPE_HG, $cb = undef ) {
 }
 
 # SCM CLONE
-sub scm_clone ( $self, $root, $uri, @args ) {
+sub scm_clone ( $self, $root, $uri, $local_scm_type, @args ) {
     my $cb = ref $args[-1] eq 'CODE' ? pop @args : undef;
 
     # can't clone to existed directory
@@ -93,9 +90,7 @@ sub scm_clone ( $self, $root, $uri, @args ) {
         return;
     }
 
-    my $upstream = Pcore::API::SCM::Upstream->new( { uri => $uri } );
-
-    my $server = $self->_get_server( $upstream->local_scm_type );
+    my $server = $self->_get_server($local_scm_type);
 
     my $temp = P->file->tempdir;
 
@@ -104,14 +99,7 @@ sub scm_clone ( $self, $root, $uri, @args ) {
     $server->scm_clone(
         $root,
         sub ($res) {
-            if ( $res->is_success ) {
-                P->file->move( $temp->path, $root );
-
-                $res = $self->new($root);
-            }
-            else {
-                undef $root;
-            }
+            P->file->move( $temp->path, $root ) if $res;
 
             $cb->($res) if $cb;
 
@@ -119,19 +107,19 @@ sub scm_clone ( $self, $root, $uri, @args ) {
 
             return;
         },
-        [ $temp->path, $uri, @args, ]
+        [ $temp->path, $uri, @args ]
     );
 
     return $blocking_cv ? $blocking_cv->recv : ();
 }
 
 sub _get_server ( $self, $type ) {
-    if ( $type == $SCM_TYPE_HG ) {
+    if ( $type eq $SCM_TYPE_HG ) {
         require Pcore::API::SCM::Server::Hg;
 
         return Pcore::API::SCM::Server::Hg->new;
     }
-    elsif ( $type == $SCM_TYPE_GIT ) {
+    elsif ( $type eq $SCM_TYPE_GIT ) {
         require Pcore::API::SCM::Server::Git;
 
         return Pcore::API::SCM::Server::Git->new;
@@ -211,7 +199,7 @@ sub _request ( $self, $method, $args ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 54                   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 51, 83               | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
